formattools.get_grob_revert_format_contributions
================================================

.. autofunction:: abjad.tools.formattools.get_grob_revert_format_contributions.get_grob_revert_format_contributions
   :noindex:
